#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:		qubes-kernel-vm-support
Version:	4.1.6
Release:	1%{?dist}
Summary:	Qubes VM initramfs modules
Source0:    qubes-utils-%{version}.tar.gz

Group:		Qubes
Vendor:     Invisible Things Lab
License:	GPL v2 only
URL:		http://www.qubes-os.org

Requires:	dracut

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Wed Apr 01 2020 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils

* Wed Apr 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 20505a8
- version 4.1.6

* Sun Mar 29 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - a631e3b
- Image.get_from_stream_async(): fix large sizes

* Sun Mar 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 37248f5
- version 4.1.5

* Tue Mar 17 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 42236a8
- Image.get_through_dvm: support Python 3

* Tue Mar 17 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1113bf3
- version 4.1.4

* Mon Mar 16 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 0213740
- Image.get_through_dvm: update for Python 3

* Fri Mar 13 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 84a6d0c
- Drop Python 2 support

* Fri Mar 13 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - eda2741
- Add Image.get_from_stream_async

* Wed Jan 22 2020 Rusty Bird <rustybird@net-c.com> - 9debe18
- Remove syncfs fallback for ancient glibc (Debian 7)

* Sat Jan 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 29a0c0e
- travis: switch to dom0 Fedora 31

* Sat Dec 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3a0a629
- version 4.1.3

* Sat Dec 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2ba9fd6
- debian: fix dependencies of qubes-kernel-vm-support pkg

* Thu Dec 05 2019 Patrick Schleizer <adrelanos@riseup.net> - 8821906
- qubes-kernel-vm-support.postinst run update-grub

* Thu Dec 05 2019 Patrick Schleizer <adrelanos@riseup.net> - 34c8212
- qubes-kernel-vm-support.preinst create folder /boot/grub

* Wed Oct 23 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9f0dc7d
- travis: update python versions

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c110f98
- travis: switch to bionic

* Tue Sep 24 2019 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - 699e10c
- partition full volatile for non-COW setups too

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 82a44bc
- version 4.1.2

* Fri Sep 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bd55c1e
- Disable BLS config style in grub

* Tue Sep 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ba6be8d
- rpm: update python2 deps

* Tue Jul 09 2019 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - ecc0b70
- align volatile swap partition to 1Mb instead of 512b

* Mon Jun 10 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 81c64d5
- version 4.1.1

* Sun Jun 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8418891
- initrd: mount / rw for the overlayfs setup time

* Sat Jun 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 66a6e33
- version 4.1.0

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d48e497
- travis: update to R4.1

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c046807
- Remove u2mfn module

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7486078
- Remove qrexec related files

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 042b671
- version 4.0.24

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9c6c825
- initramfs: use overlayfs for /lib/modules, if available

* Wed Jun 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e7c90c7
- Declare u2mfn module version, skip build for qubes kernels

* Wed Jun 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f365d7c
- travis: remove older Fedora releases and add Fedora 30

* Tue Jun 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2b84113
- travis: switch to xenial

* Tue Jun 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e00a64a
- python3: use macro pkgversion

* Mon Feb 25 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 24a25cc
- version 4.0.23

* Mon Feb 25 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - de2150e
- Add xen_scrub_pages=0 kernel option only if initramfs was rebuilt

* Mon Feb 25 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad790a5
- Really install xen-scrub-pages dracut module

* Tue Feb 19 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2c69601
- Do not use /proc/xen for detecting dom0 anymore

* Sat Feb 16 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4fe08d3
- Adjust permissions of /dev/xen/hypercall

* Fri Feb 15 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - da61cb7
- dracut: add a flag file indicating scrub-pages option support

* Wed Feb 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5eb526d
- dracut: fix checking for "Root filesystem" label, improve udev sync

* Wed Feb 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 456fe99
- Disable scrubbing memory pages during initial balloon down

* Mon Oct 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 14be8aa
- version 4.0.22

* Fri Oct 26 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4543ab1
- tests: skip the other img converter test too

* Wed Oct 17 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4bfd10b
- imgconverter: allow icons up to 2048x2048

* Tue Oct 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0255f4d
- tests: skip img converter test if qubes-img-converter is not installed

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e2d7f08
- version 4.0.21

* Mon Oct 08 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 76fa9c9
- travis: update Fedora and Debian versions

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ca9f13
- rpm: adjust for fc29

* Thu Sep 06 2018 Rusty Bird <rustybird@net-c.com> - 6cd4a1b
- Order qubes-meminfo-writer-dom0 before systemd-user-sessions

* Tue Jul 03 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ab7ca7b
- version 4.0.20

